@@ -1,9 +1,11 @@
 import os
 import re
+import sys
+import typing
 from collections import OrderedDict
 from itertools import zip_longest
 from string import Template
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Tuple, Type, Union
 
 from packaging.version import Version
 
@@ -11,6 +13,12 @@ from commitizen.defaults import MAJOR, MINOR, PATCH, bump_message
 from commitizen.exceptions import CurrentVersionNotFoundError
 from commitizen.git import GitCommit, smart_open
 
+if sys.version_info >= (3, 8):
+    from commitizen.version_types import VersionProtocol
+else:
+    # workaround mypy issue for 3.7 python
+    VersionProtocol = typing.Any
+
 
 def find_increment(
     commits: List[GitCommit], regex: str, increments_map: Union[dict, OrderedDict]
@@ -120,7 +128,8 @@ def generate_version(
     prerelease_offset: int = 0,
     devrelease: Optional[int] = None,
     is_local_version: bool = False,
-) -> Version:
+    version_type_cls: Optional[Type[VersionProtocol]] = None,
+) -> VersionProtocol:
     """Based on the given increment a proper semver will be generated.
 
     For now the rules and versioning scheme is based on
@@ -132,15 +141,17 @@ def generate_version(
         MINOR 1.0.0 -> 1.1.0
         MAJOR 1.0.0 -> 2.0.0
     """
+    if version_type_cls is None:
+        version_type_cls = Version
     if is_local_version:
-        version = Version(current_version)
+        version = version_type_cls(current_version)
         dev_version = devrelease_generator(devrelease=devrelease)
         pre_version = prerelease_generator(
             str(version.local), prerelease=prerelease, offset=prerelease_offset
         )
         semver = semver_generator(str(version.local), increment=increment)
 
-        return Version(f"{version.public}+{semver}{pre_version}{dev_version}")
+        return version_type_cls(f"{version.public}+{semver}{pre_version}{dev_version}")
     else:
         dev_version = devrelease_generator(devrelease=devrelease)
         pre_version = prerelease_generator(
@@ -149,7 +160,7 @@ def generate_version(
         semver = semver_generator(current_version, increment=increment)
 
         # TODO: post version
-        return Version(f"{semver}{pre_version}{dev_version}")
+        return version_type_cls(f"{semver}{pre_version}{dev_version}")
 
 
 def update_version_in_files(
@@ -208,7 +219,9 @@ def _version_to_regex(version: str) -> str:
 
 
 def normalize_tag(
-    version: Union[Version, str], tag_format: Optional[str] = None
+    version: Union[VersionProtocol, str],
+    tag_format: Optional[str] = None,
+    version_type_cls: Optional[Type[VersionProtocol]] = None,
 ) -> str:
     """The tag and the software version might be different.
 
@@ -221,8 +234,10 @@ def normalize_tag(
     | ver1.0.0 | 1.0.0 |
     | ver1.0.0.a0 | 1.0.0a0 |
     """
+    if version_type_cls is None:
+        version_type_cls = Version
     if isinstance(version, str):
-        version = Version(version)
+        version = version_type_cls(version)
 
     if not tag_format:
         return str(version)
